@@ -1,5 +1,5 @@
 /*
- *  $Id: test.cc,v 1.4 1999/05/11 17:03:43 sbooth Exp $
+ *  $Id: test.cc,v 1.6 1999/06/01 19:34:56 sbooth Exp $
  *
  *  Copyright (C) 1996, 1997, 1998, 1999 Stephen F. Booth
  *
@@ -128,7 +128,8 @@ main(int argc,
     cout << comment() << "This page generated by Cgicc for "
 	 << env.getRemoteHost() << comment() << endl;
     cout << h4() << "Thanks for using Cgi" << span("cc", add("class", "red")) 
-	 << ", " << env.getRemoteHost() << '!' << h4() << endl;  
+	 << ", " << env.getRemoteHost() 
+	 << '(' << env.getRemoteAddr() << ")!" << h4() << endl;  
     
     // If the user wants to save the submission, do it
     if(cgi.queryCheckbox("save")) {
@@ -185,7 +186,7 @@ main(int argc,
     
     // Information on Cgicc
     cout << CGICCNS div(add("align","center").add("class","smaller")) << endl;
-    cout << "Cgi" << span("cc", add("class","red")) << " v";
+    cout << "GNU Cgi" << span("cc", add("class","red")) << " v";
     cout << cgi.getVersion();
     cout << " by " << a("Stephen F. Booth", 
 			add("href", "http://www.lmi.net/~sbooth/")) 
