@@ -1,5 +1,5 @@
 /*
- *  $Id: MStreamable.cc,v 1.5 1999/04/26 22:42:34 sbooth Exp $
+ *  $Id: MStreamable.cc,v 1.6 1999/05/25 19:16:49 sbooth Exp $
  *
  *  Copyright (C) 1996, 1997, 1998, 1999 Stephen F. Booth
  *
@@ -18,6 +18,10 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef __GNUG__
+#pragma implementation
+#endif
+
 #include "MStreamable.hh"
 
 // ============================================================
